@@ -1,13 +1,14 @@
 package completion
 
 import (
+	"context"
 	"embed"
 	"fmt"
 	"os"
 	"slices"
 	"strings"
 
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli/v3"
 
 	"github.com/ekristen/aws-nuke/v3/pkg/commands/global"
 	"github.com/ekristen/aws-nuke/v3/pkg/common"
@@ -16,7 +17,7 @@ import (
 //go:embed files/*
 var files embed.FS
 
-func execute(c *cli.Context) error {
+func execute(_ context.Context, c *cli.Command) error {
 	var autocomplete []byte
 	var err error
 	switch c.String("shell") {
@@ -47,7 +48,7 @@ func init() {
 			Name:  "shell",
 			Usage: "shell to generate completion script for",
 			Value: shellValue,
-			Action: func(c *cli.Context, val string) error {
+			Action: func(ctx context.Context, c *cli.Command, val string) error {
 				validShells := []string{"bash", "zsh"}
 				if !slices.Contains(validShells, val) {
 					return fmt.Errorf("unsupported shell %s", val)
