@@ -82,6 +82,7 @@ func TestConfig_LoadExample(t *testing.T) {
 					Filters: filter.Filters{
 						"S3Bucket": {
 							filter.Filter{
+								Group:  "default",
 								Type:   filter.Glob,
 								Value:  "my-statebucket-*",
 								Values: []string{},
@@ -159,6 +160,7 @@ func TestConfig_NoBlocklistTermsProd(t *testing.T) {
 					Filters: filter.Filters{
 						"S3Bucket": {
 							filter.Filter{
+								Group:  "default",
 								Type:   filter.Glob,
 								Value:  "my-statebucket-*",
 								Values: []string{},
@@ -343,17 +345,22 @@ func TestConfig_FilterMerge(t *testing.T) {
 	expect := filter.Filters{
 		"S3Bucket": []filter.Filter{
 			{
-				Type: "glob", Value: "my-statebucket-*", Values: []string{},
+				Group:  "default",
+				Type:   "glob",
+				Value:  "my-statebucket-*",
+				Values: []string{},
 			},
 		},
 		"IAMRole": []filter.Filter{
 			{
+				Group: "default",
 				Type:  "exact",
 				Value: "uber.admin",
 			},
 		},
 		"IAMRolePolicyAttachment": []filter.Filter{
 			{
+				Group: "default",
 				Type:  "exact",
 				Value: "uber.admin -> AdministratorAccess",
 			},
