@@ -1,26 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/apigateway"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type APIGatewayVpcLink struct {
-	svc       *apigateway.APIGateway
-	vpcLinkID *string
-	name      *string
-	tags      map[string]*string
-}
+const APIGatewayVpcLinkResource = "APIGatewayVpcLink"
 
 func init() {
-	register("APIGatewayVpcLink", ListAPIGatewayVpcLinks)
+	registry.Register(&registry.Registration{
+		Name:     APIGatewayVpcLinkResource,
+		Scope:    nuke.Account,
+		Resource: &APIGatewayVpcLink{},
+		Lister:   &APIGatewayVpcLinkLister{},
+	})
 }
 
-func ListAPIGatewayVpcLinks(sess *session.Session) ([]Resource, error) {
-	svc := apigateway.New(sess)
-	resources := []Resource{}
+type APIGatewayVpcLinkLister struct{}
+
+func (l *APIGatewayVpcLinkLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+	svc := apigateway.New(opts.Session)
+	var resources []resource.Resource
 
 	params := &apigateway.GetVpcLinksInput{
 		Limit: aws.Int64(100),
@@ -51,8 +60,14 @@ func ListAPIGatewayVpcLinks(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *APIGatewayVpcLink) Remove() error {
+type APIGatewayVpcLink struct {
+	svc       *apigateway.APIGateway
+	vpcLinkID *string
+	name      *string
+	tags      map[string]*string
+}
 
+func (f *APIGatewayVpcLink) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteVpcLink(&apigateway.DeleteVpcLinkInput{
 		VpcLinkId: f.vpcLinkID,
 	})
