@@ -1,28 +1,45 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
-	"github.com/aws/aws-sdk-go/service/appconfig"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+	"context"
+
 	"github.com/sirupsen/logrus"
+
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/appconfig"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppConfigConfigurationProfile struct {
-	svc           *appconfig.AppConfig
-	applicationId *string
-	id            *string
-	name          *string
-}
+const AppConfigConfigurationProfileResource = "AppConfigConfigurationProfile"
 
 func init() {
-	register("AppConfigConfigurationProfile", ListAppConfigConfigurationProfiles)
+	registry.Register(&registry.Registration{
+		Name:     AppConfigConfigurationProfileResource,
+		Scope:    nuke.Account,
+		Resource: &AppConfigConfigurationProfile{},
+		Lister:   &AppConfigConfigurationProfileLister{},
+		DependsOn: []string{
+			AppConfigHostedConfigurationVersionResource,
+		},
+	})
 }
 
-func ListAppConfigConfigurationProfiles(sess *session.Session) ([]Resource, error) {
-	svc := appconfig.New(sess)
-	resources := []Resource{}
-	applications, err := ListAppConfigApplications(sess)
+type AppConfigConfigurationProfileLister struct{}
+
+func (l *AppConfigConfigurationProfileLister) List(ctx context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appconfig.New(opts.Session)
+	resources := make([]resource.Resource, 0)
+
+	applicationLister := &AppConfigApplicationLister{}
+
+	applications, err := applicationLister.List(ctx, o)
 	if err != nil {
 		return nil, err
 	}
@@ -40,7 +57,7 @@ func ListAppConfigConfigurationProfiles(sess *session.Session) ([]Resource, erro
 			for _, item := range page.Items {
 				resources = append(resources, &AppConfigConfigurationProfile{
 					svc:           svc,
-					applicationId: application.id,
+					applicationID: application.id,
 					id:            item.Id,
 					name:          item.Name,
 				})
@@ -54,9 +71,16 @@ func ListAppConfigConfigurationProfiles(sess *session.Session) ([]Resource, erro
 	return resources, nil
 }
 
-func (f *AppConfigConfigurationProfile) Remove() error {
+type AppConfigConfigurationProfile struct {
+	svc           *appconfig.AppConfig
+	applicationID *string
+	id            *string
+	name          *string
+}
+
+func (f *AppConfigConfigurationProfile) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteConfigurationProfile(&appconfig.DeleteConfigurationProfileInput{
-		ApplicationId:          f.applicationId,
+		ApplicationId:          f.applicationID,
 		ConfigurationProfileId: f.id,
 	})
 	return err
@@ -64,7 +88,7 @@ func (f *AppConfigConfigurationProfile) Remove() error {
 
 func (f *AppConfigConfigurationProfile) Properties() types.Properties {
 	return types.NewProperties().
-		Set("ApplicationID", f.applicationId).
+		Set("ApplicationID", f.applicationID).
 		Set("ID", f.id).
 		Set("Name", f.name)
 }
