@@ -1,28 +1,41 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
-	"github.com/aws/aws-sdk-go/service/appconfig"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+	"context"
+
 	"github.com/sirupsen/logrus"
+
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/appconfig"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppConfigEnvironment struct {
-	svc           *appconfig.AppConfig
-	applicationId *string
-	id            *string
-	name          *string
-}
+const AppConfigEnvironmentResource = "AppConfigEnvironment"
 
 func init() {
-	register("AppConfigEnvironment", ListAppConfigEnvironments)
+	registry.Register(&registry.Registration{
+		Name:     AppConfigEnvironmentResource,
+		Scope:    nuke.Account,
+		Resource: &AppConfigEnvironment{},
+		Lister:   &AppConfigEnvironmentLister{},
+	})
 }
 
-func ListAppConfigEnvironments(sess *session.Session) ([]Resource, error) {
-	svc := appconfig.New(sess)
-	resources := []Resource{}
-	applications, err := ListAppConfigApplications(sess)
+type AppConfigEnvironmentLister struct{}
+
+func (l *AppConfigEnvironmentLister) List(ctx context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appconfig.New(opts.Session)
+	resources := make([]resource.Resource, 0)
+
+	applicationLister := &AppConfigApplicationLister{}
+	applications, err := applicationLister.List(ctx, o)
 	if err != nil {
 		return nil, err
 	}
@@ -40,7 +53,7 @@ func ListAppConfigEnvironments(sess *session.Session) ([]Resource, error) {
 			for _, item := range page.Items {
 				resources = append(resources, &AppConfigEnvironment{
 					svc:           svc,
-					applicationId: application.id,
+					applicationID: application.id,
 					id:            item.Id,
 					name:          item.Name,
 				})
@@ -54,9 +67,16 @@ func ListAppConfigEnvironments(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppConfigEnvironment) Remove() error {
+type AppConfigEnvironment struct {
+	svc           *appconfig.AppConfig
+	applicationID *string
+	id            *string
+	name          *string
+}
+
+func (f *AppConfigEnvironment) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteEnvironment(&appconfig.DeleteEnvironmentInput{
-		ApplicationId: f.applicationId,
+		ApplicationId: f.applicationID,
 		EnvironmentId: f.id,
 	})
 	return err
@@ -64,7 +84,7 @@ func (f *AppConfigEnvironment) Remove() error {
 
 func (f *AppConfigEnvironment) Properties() types.Properties {
 	return types.NewProperties().
-		Set("ApplicationID", f.applicationId).
+		Set("ApplicationID", f.applicationID).
 		Set("ID", f.id).
 		Set("Name", f.name)
 }
