@@ -1,22 +1,33 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/appstream"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
 )
 
-type AppStreamFleet struct {
-	svc  *appstream.AppStream
-	name *string
-}
+const AppStreamFleetResource = "AppStreamFleet"
 
 func init() {
-	register("AppStreamFleet", ListAppStreamFleets)
+	registry.Register(&registry.Registration{
+		Name:     AppStreamFleetResource,
+		Scope:    nuke.Account,
+		Resource: &AppStreamFleet{},
+		Lister:   &AppStreamFleetLister{},
+	})
 }
 
-func ListAppStreamFleets(sess *session.Session) ([]Resource, error) {
-	svc := appstream.New(sess)
-	resources := []Resource{}
+type AppStreamFleetLister struct{}
+
+func (l *AppStreamFleetLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appstream.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &appstream.DescribeFleetsInput{}
 
@@ -43,8 +54,12 @@ func ListAppStreamFleets(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppStreamFleet) Remove() error {
+type AppStreamFleet struct {
+	svc  *appstream.AppStream
+	name *string
+}
 
+func (f *AppStreamFleet) Remove(_ context.Context) error {
 	_, err := f.svc.StopFleet(&appstream.StopFleetInput{
 		Name: f.name,
 	})
