@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/appstream"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppStreamImageBuilder struct {
-	svc  *appstream.AppStream
-	name *string
-}
+const AppStreamImageBuilderResource = "AppStreamImageBuilder"
 
 func init() {
-	register("AppStreamImageBuilder", ListAppStreamImageBuilders)
+	registry.Register(&registry.Registration{
+		Name:     AppStreamImageBuilderResource,
+		Scope:    nuke.Account,
+		Resource: &AppStreamImageBuilder{},
+		Lister:   &AppStreamImageBuilderLister{},
+	})
 }
 
-func ListAppStreamImageBuilders(sess *session.Session) ([]Resource, error) {
-	svc := appstream.New(sess)
-	resources := []Resource{}
+type AppStreamImageBuilderLister struct{}
+
+func (l *AppStreamImageBuilderLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appstream.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &appstream.DescribeImageBuildersInput{
 		MaxResults: aws.Int64(100),
@@ -46,8 +58,12 @@ func ListAppStreamImageBuilders(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppStreamImageBuilder) Remove() error {
+type AppStreamImageBuilder struct {
+	svc  *appstream.AppStream
+	name *string
+}
 
+func (f *AppStreamImageBuilder) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteImageBuilder(&appstream.DeleteImageBuilderInput{
 		Name: f.name,
 	})
