@@ -1,26 +1,38 @@
 package resources
 
 import (
+	"context"
 	"fmt"
 
+	"github.com/gotidy/ptr"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/appstream"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppStreamImageBuilderWaiter struct {
-	svc   *appstream.AppStream
-	name  *string
-	state *string
-}
+const AppStreamImageBuilderWaiterResource = "AppStreamImageBuilderWaiter"
 
 func init() {
-	register("AppStreamImageBuilderWaiter", ListAppStreamImageBuilderWaiters)
+	registry.Register(&registry.Registration{
+		Name:     AppStreamImageBuilderWaiterResource,
+		Scope:    nuke.Account,
+		Resource: &AppStreamImageBuilderWaiter{},
+		Lister:   &AppStreamImageBuilderWaiterLister{},
+	})
 }
 
-func ListAppStreamImageBuilderWaiters(sess *session.Session) ([]Resource, error) {
-	svc := appstream.New(sess)
-	resources := []Resource{}
+type AppStreamImageBuilderWaiterLister struct{}
+
+func (l *AppStreamImageBuilderWaiterLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appstream.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &appstream.DescribeImageBuildersInput{
 		MaxResults: aws.Int64(100),
@@ -50,8 +62,13 @@ func ListAppStreamImageBuilderWaiters(sess *session.Session) ([]Resource, error)
 	return resources, nil
 }
 
-func (f *AppStreamImageBuilderWaiter) Remove() error {
+type AppStreamImageBuilderWaiter struct {
+	svc   *appstream.AppStream
+	name  *string
+	state *string
+}
 
+func (f *AppStreamImageBuilderWaiter) Remove(_ context.Context) error {
 	return nil
 }
 
@@ -60,11 +77,11 @@ func (f *AppStreamImageBuilderWaiter) String() string {
 }
 
 func (f *AppStreamImageBuilderWaiter) Filter() error {
-	if *f.state == "STOPPED" {
+	if ptr.ToString(f.state) == appstream.ImageBuilderStateStopped {
 		return fmt.Errorf("already stopped")
-	} else if *f.state == "RUNNING" {
+	} else if ptr.ToString(f.state) == appstream.ImageBuilderStateRunning {
 		return fmt.Errorf("already running")
-	} else if *f.state == "DELETING" {
+	} else if ptr.ToString(f.state) == appstream.ImageBuilderStateDeleting {
 		return fmt.Errorf("already being deleted")
 	}
 
