@@ -1,22 +1,34 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/cloudwatch"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type CloudWatchDashboard struct {
-	svc           *cloudwatch.CloudWatch
-	dashboardName *string
-}
+const CloudWatchDashboardResource = "CloudWatchDashboard"
 
 func init() {
-	register("CloudWatchDashboard", ListCloudWatchDashboards)
+	registry.Register(&registry.Registration{
+		Name:     CloudWatchDashboardResource,
+		Scope:    nuke.Account,
+		Resource: &CloudWatchDashboard{},
+		Lister:   &CloudWatchDashboardLister{},
+	})
 }
 
-func ListCloudWatchDashboards(sess *session.Session) ([]Resource, error) {
-	svc := cloudwatch.New(sess)
-	resources := []Resource{}
+type CloudWatchDashboardLister struct{}
+
+func (l *CloudWatchDashboardLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := cloudwatch.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &cloudwatch.ListDashboardsInput{}
 
@@ -43,8 +55,12 @@ func ListCloudWatchDashboards(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *CloudWatchDashboard) Remove() error {
+type CloudWatchDashboard struct {
+	svc           *cloudwatch.CloudWatch
+	dashboardName *string
+}
 
+func (f *CloudWatchDashboard) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteDashboards(&cloudwatch.DeleteDashboardsInput{
 		DashboardNames: []*string{f.dashboardName},
 	})
