@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/databasemigrationservice"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type DatabaseMigrationServiceReplicationInstance struct {
-	svc *databasemigrationservice.DatabaseMigrationService
-	ARN *string
-}
+const DatabaseMigrationServiceReplicationInstanceResource = "DatabaseMigrationServiceReplicationInstance"
 
 func init() {
-	register("DatabaseMigrationServiceReplicationInstance", ListDatabaseMigrationServiceReplicationInstances)
+	registry.Register(&registry.Registration{
+		Name:     DatabaseMigrationServiceReplicationInstanceResource,
+		Scope:    nuke.Account,
+		Resource: &DatabaseMigrationServiceReplicationInstance{},
+		Lister:   &DatabaseMigrationServiceReplicationInstanceLister{},
+	})
 }
 
-func ListDatabaseMigrationServiceReplicationInstances(sess *session.Session) ([]Resource, error) {
-	svc := databasemigrationservice.New(sess)
-	resources := []Resource{}
+type DatabaseMigrationServiceReplicationInstanceLister struct{}
+
+func (l *DatabaseMigrationServiceReplicationInstanceLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := databasemigrationservice.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &databasemigrationservice.DescribeReplicationInstancesInput{
 		MaxRecords: aws.Int64(100),
@@ -46,8 +58,12 @@ func ListDatabaseMigrationServiceReplicationInstances(sess *session.Session) ([]
 	return resources, nil
 }
 
-func (f *DatabaseMigrationServiceReplicationInstance) Remove() error {
+type DatabaseMigrationServiceReplicationInstance struct {
+	svc *databasemigrationservice.DatabaseMigrationService
+	ARN *string
+}
 
+func (f *DatabaseMigrationServiceReplicationInstance) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteReplicationInstance(&databasemigrationservice.DeleteReplicationInstanceInput{
 		ReplicationInstanceArn: f.ARN,
 	})
