@@ -1,28 +1,41 @@
 package resources
 
 import (
+	"context"
+
 	"fmt"
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ec2"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type EC2Snapshot struct {
-	svc       *ec2.EC2
-	id        string
-	startTime *time.Time
-	tags      []*ec2.Tag
-}
+const EC2SnapshotResource = "EC2Snapshot"
 
 func init() {
-	register("EC2Snapshot", ListEC2Snapshots)
+	registry.Register(&registry.Registration{
+		Name:     EC2SnapshotResource,
+		Scope:    nuke.Account,
+		Resource: &EC2Snapshot{},
+		Lister:   &EC2SnapshotLister{},
+		DependsOn: []string{
+			EC2ImageResource,
+		},
+	})
 }
 
-func ListEC2Snapshots(sess *session.Session) ([]Resource, error) {
-	svc := ec2.New(sess)
+type EC2SnapshotLister struct{}
+
+func (l *EC2SnapshotLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := ec2.New(opts.Session)
 	params := &ec2.DescribeSnapshotsInput{
 		OwnerIds: []*string{
 			aws.String("self"),
@@ -33,7 +46,7 @@ func ListEC2Snapshots(sess *session.Session) ([]Resource, error) {
 		return nil, err
 	}
 
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 	for _, out := range resp.Snapshots {
 		resources = append(resources, &EC2Snapshot{
 			svc:       svc,
@@ -46,6 +59,13 @@ func ListEC2Snapshots(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+type EC2Snapshot struct {
+	svc       *ec2.EC2
+	id        string
+	startTime *time.Time
+	tags      []*ec2.Tag
+}
+
 func (e *EC2Snapshot) Properties() types.Properties {
 	properties := types.NewProperties()
 	properties.Set("StartTime", e.startTime.Format(time.RFC3339))
@@ -56,7 +76,7 @@ func (e *EC2Snapshot) Properties() types.Properties {
 	return properties
 }
 
-func (e *EC2Snapshot) Remove() error {
+func (e *EC2Snapshot) Remove(_ context.Context) error {
 	_, err := e.svc.DeleteSnapshot(&ec2.DeleteSnapshotInput{
 		SnapshotId: &e.id,
 	})
