@@ -1,26 +1,37 @@
 package resources
 
 import (
+	"context"
+
 	"fmt"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ecs"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type ECSService struct {
-	svc        *ecs.ECS
-	serviceARN *string
-	clusterARN *string
-}
+const ECSServiceResource = "ECSService"
 
 func init() {
-	register("ECSService", ListECSServices)
+	registry.Register(&registry.Registration{
+		Name:     ECSServiceResource,
+		Scope:    nuke.Account,
+		Resource: &ECSService{},
+		Lister:   &ECSServiceLister{},
+	})
 }
 
-func ListECSServices(sess *session.Session) ([]Resource, error) {
-	svc := ecs.New(sess)
-	resources := []Resource{}
+type ECSServiceLister struct{}
+
+func (l *ECSServiceLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := ecs.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 	clusters := []*string{}
 
 	clusterParams := &ecs.ListClustersInput{
@@ -34,9 +45,7 @@ func ListECSServices(sess *session.Session) ([]Resource, error) {
 			return nil, err
 		}
 
-		for _, clusterArn := range output.ClusterArns {
-			clusters = append(clusters, clusterArn)
-		}
+		clusters = append(clusters, output.ClusterArns...)
 
 		if output.NextToken == nil {
 			break
@@ -52,26 +61,39 @@ func ListECSServices(sess *session.Session) ([]Resource, error) {
 			Cluster:    clusterArn,
 			MaxResults: aws.Int64(10),
 		}
-		err := svc.ListServicesPages(serviceParams, func(page *ecs.ListServicesOutput, lastPage bool) bool {
-			for _, serviceArn := range page.ServiceArns {
+
+		for {
+			output, err := svc.ListServices(serviceParams)
+			if err != nil {
+				return nil, err
+			}
+
+			for _, serviceArn := range output.ServiceArns {
 				resources = append(resources, &ECSService{
 					svc:        svc,
 					serviceARN: serviceArn,
 					clusterARN: clusterArn,
 				})
 			}
-			return true
-		})
-		if err != nil {
-			return nil, err
+
+			if output.NextToken == nil {
+				break
+			}
+
+			serviceParams.NextToken = output.NextToken
 		}
 	}
 
 	return resources, nil
 }
 
-func (f *ECSService) Remove() error {
+type ECSService struct {
+	svc        *ecs.ECS
+	serviceARN *string
+	clusterARN *string
+}
 
+func (f *ECSService) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteService(&ecs.DeleteServiceInput{
 		Cluster: f.clusterARN,
 		Service: f.serviceARN,
