@@ -1,23 +1,37 @@
 package resources
 
 import (
+	"context"
+
+	"github.com/gotidy/ptr"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/glue"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type GlueDevEndpoint struct {
-	svc          *glue.Glue
-	endpointName *string
-}
+const GlueDevEndpointResource = "GlueDevEndpoint"
 
 func init() {
-	register("GlueDevEndpoint", ListGlueDevEndpoints)
+	registry.Register(&registry.Registration{
+		Name:     GlueDevEndpointResource,
+		Scope:    nuke.Account,
+		Resource: &GlueDevEndpoint{},
+		Lister:   &GlueDevEndpointLister{},
+	})
 }
 
-func ListGlueDevEndpoints(sess *session.Session) ([]Resource, error) {
-	svc := glue.New(sess)
-	resources := []Resource{}
+type GlueDevEndpointLister struct{}
+
+func (l *GlueDevEndpointLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := glue.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &glue.GetDevEndpointsInput{
 		MaxResults: aws.Int64(100),
@@ -37,7 +51,7 @@ func ListGlueDevEndpoints(sess *session.Session) ([]Resource, error) {
 		}
 
 		// This one API can and does return an empty string
-		if output.NextToken == nil || len(*output.NextToken) == 0 {
+		if output.NextToken == nil || ptr.ToString(output.NextToken) == "" {
 			break
 		}
 
@@ -47,8 +61,12 @@ func ListGlueDevEndpoints(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *GlueDevEndpoint) Remove() error {
+type GlueDevEndpoint struct {
+	svc          *glue.Glue
+	endpointName *string
+}
 
+func (f *GlueDevEndpoint) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteDevEndpoint(&glue.DeleteDevEndpointInput{
 		EndpointName: f.endpointName,
 	})
