@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iot"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type IoTCACertificate struct {
-	svc *iot.IoT
-	ID  *string
-}
+const IoTCACertificateResource = "IoTCACertificate"
 
 func init() {
-	register("IoTCACertificate", ListIoTCACertificates)
+	registry.Register(&registry.Registration{
+		Name:     IoTCACertificateResource,
+		Scope:    nuke.Account,
+		Resource: &IoTCACertificate{},
+		Lister:   &IoTCACertificateLister{},
+	})
 }
 
-func ListIoTCACertificates(sess *session.Session) ([]Resource, error) {
-	svc := iot.New(sess)
-	resources := []Resource{}
+type IoTCACertificateLister struct{}
+
+func (l *IoTCACertificateLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := iot.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &iot.ListCACertificatesInput{}
 
@@ -36,8 +48,12 @@ func ListIoTCACertificates(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *IoTCACertificate) Remove() error {
+type IoTCACertificate struct {
+	svc *iot.IoT
+	ID  *string
+}
 
+func (f *IoTCACertificate) Remove(_ context.Context) error {
 	_, err := f.svc.UpdateCACertificate(&iot.UpdateCACertificateInput{
 		CertificateId: f.ID,
 		NewStatus:     aws.String("INACTIVE"),
