@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iot"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type IoTOTAUpdate struct {
-	svc *iot.IoT
-	ID  *string
-}
+const IoTOTAUpdateResource = "IoTOTAUpdate"
 
 func init() {
-	register("IoTOTAUpdate", ListIoTOTAUpdates)
+	registry.Register(&registry.Registration{
+		Name:     IoTOTAUpdateResource,
+		Scope:    nuke.Account,
+		Resource: &IoTOTAUpdate{},
+		Lister:   &IoTOTAUpdateLister{},
+	})
 }
 
-func ListIoTOTAUpdates(sess *session.Session) ([]Resource, error) {
-	svc := iot.New(sess)
-	resources := []Resource{}
+type IoTOTAUpdateLister struct{}
+
+func (l *IoTOTAUpdateLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := iot.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &iot.ListOTAUpdatesInput{
 		MaxResults: aws.Int64(100),
@@ -44,8 +56,12 @@ func ListIoTOTAUpdates(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *IoTOTAUpdate) Remove() error {
+type IoTOTAUpdate struct {
+	svc *iot.IoT
+	ID  *string
+}
 
+func (f *IoTOTAUpdate) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteOTAUpdate(&iot.DeleteOTAUpdateInput{
 		OtaUpdateId: f.ID,
 	})
