@@ -1,23 +1,35 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/lambda"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type LambdaEventSourceMapping struct {
-	svc     *lambda.Lambda
-	mapping *lambda.EventSourceMappingConfiguration
-}
+const LambdaEventSourceMappingResource = "LambdaEventSourceMapping"
 
 func init() {
-	register("LambdaEventSourceMapping", ListLambdaEventSourceMapping)
+	registry.Register(&registry.Registration{
+		Name:     LambdaEventSourceMappingResource,
+		Scope:    nuke.Account,
+		Resource: &LambdaEventSourceMapping{},
+		Lister:   &LambdaEventSourceMappingLister{},
+	})
 }
 
-func ListLambdaEventSourceMapping(sess *session.Session) ([]Resource, error) {
-	svc := lambda.New(sess)
-	resources := []Resource{}
+type LambdaEventSourceMappingLister struct{}
+
+func (l *LambdaEventSourceMappingLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := lambda.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &lambda.ListEventSourceMappingsInput{}
 	for {
@@ -43,7 +55,12 @@ func ListLambdaEventSourceMapping(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (m *LambdaEventSourceMapping) Remove() error {
+type LambdaEventSourceMapping struct {
+	svc     *lambda.Lambda
+	mapping *lambda.EventSourceMappingConfiguration
+}
+
+func (m *LambdaEventSourceMapping) Remove(_ context.Context) error {
 	_, err := m.svc.DeleteEventSourceMapping(&lambda.DeleteEventSourceMappingInput{
 		UUID: m.mapping.UUID,
 	})
@@ -57,5 +74,6 @@ func (m *LambdaEventSourceMapping) Properties() types.Properties {
 	properties.Set("EventSourceArn", m.mapping.EventSourceArn)
 	properties.Set("FunctionArn", m.mapping.FunctionArn)
 	properties.Set("State", m.mapping.State)
+
 	return properties
 }
