@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/medialive"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type MediaLiveInput struct {
-	svc *medialive.MediaLive
-	ID  *string
-}
+const MediaLiveInputResource = "MediaLiveInput"
 
 func init() {
-	register("MediaLiveInput", ListMediaLiveInputs)
+	registry.Register(&registry.Registration{
+		Name:     MediaLiveInputResource,
+		Scope:    nuke.Account,
+		Resource: &MediaLiveInput{},
+		Lister:   &MediaLiveInputLister{},
+	})
 }
 
-func ListMediaLiveInputs(sess *session.Session) ([]Resource, error) {
-	svc := medialive.New(sess)
-	resources := []Resource{}
+type MediaLiveInputLister struct{}
+
+func (l *MediaLiveInputLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := medialive.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &medialive.ListInputsInput{
 		MaxResults: aws.Int64(20),
@@ -46,8 +58,12 @@ func ListMediaLiveInputs(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *MediaLiveInput) Remove() error {
+type MediaLiveInput struct {
+	svc *medialive.MediaLive
+	ID  *string
+}
 
+func (f *MediaLiveInput) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteInput(&medialive.DeleteInputInput{
 		InputId: f.ID,
 	})
