@@ -1,12 +1,54 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/kafka"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
+const MSKClusterResource = "MSKCluster"
+
+func init() {
+	registry.Register(&registry.Registration{
+		Name:     MSKClusterResource,
+		Scope:    nuke.Account,
+		Resource: &MSKCluster{},
+		Lister:   &MSKClusterLister{},
+	})
+}
+
+type MSKClusterLister struct{}
+
+func (l *MSKClusterLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := kafka.New(opts.Session)
+
+	resp, err := svc.ListClusters(&kafka.ListClustersInput{})
+	if err != nil {
+		return nil, err
+	}
+
+	resources := make([]resource.Resource, 0)
+	for _, cluster := range resp.ClusterInfoList {
+		resources = append(resources, &MSKCluster{
+			svc:  svc,
+			arn:  *cluster.ClusterArn,
+			name: *cluster.ClusterName,
+			tags: cluster.Tags,
+		})
+	}
+
+	return resources, nil
+}
+
 type MSKCluster struct {
 	svc  *kafka.Kafka
 	arn  string
@@ -14,32 +56,7 @@ type MSKCluster struct {
 	tags map[string]*string
 }
 
-func init() {
-	register("MSKCluster", ListMSKCluster)
-}
-
-func ListMSKCluster(sess *session.Session) ([]Resource, error) {
-	svc := kafka.New(sess)
-	params := &kafka.ListClustersInput{}
-	resp, err := svc.ListClusters(params)
-
-	if err != nil {
-		return nil, err
-	}
-	resources := make([]Resource, 0)
-	for _, cluster := range resp.ClusterInfoList {
-		resources = append(resources, &MSKCluster{
-			svc:  svc,
-			arn:  *cluster.ClusterArn,
-			name: *cluster.ClusterName,
-			tags: cluster.Tags,
-		})
-
-	}
-	return resources, nil
-}
-
-func (m *MSKCluster) Remove() error {
+func (m *MSKCluster) Remove(_ context.Context) error {
 	params := &kafka.DeleteClusterInput{
 		ClusterArn: &m.arn,
 	}
