@@ -1,26 +1,35 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/prometheusservice"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AMPWorkspace struct {
-	svc            *prometheusservice.PrometheusService
-	workspaceAlias *string
-	workspaceARN   *string
-	workspaceId    *string
-}
+const AMPWorkspaceResource = "AMPWorkspace"
 
 func init() {
-	register("AMPWorkspace", ListAMPWorkspaces,
-		mapCloudControl("AWS::APS::Workspace"))
+	registry.Register(&registry.Registration{
+		Name:     AMPWorkspaceResource,
+		Scope:    nuke.Account,
+		Resource: &AMPWorkspace{},
+		Lister:   &AMPWorkspaceLister{},
+	})
 }
 
-func ListAMPWorkspaces(sess *session.Session) ([]Resource, error) {
-	svc := prometheusservice.New(sess)
-	resources := []Resource{}
+type AMPWorkspaceLister struct{}
+
+func (l *AMPWorkspaceLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := prometheusservice.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	var ampWorkspaces []*prometheusservice.WorkspaceSummary
 	err := svc.ListWorkspacesPages(
@@ -39,16 +48,23 @@ func ListAMPWorkspaces(sess *session.Session) ([]Resource, error) {
 			svc:            svc,
 			workspaceAlias: ws.Alias,
 			workspaceARN:   ws.Arn,
-			workspaceId:    ws.WorkspaceId,
+			workspaceID:    ws.WorkspaceId,
 		})
 	}
 
 	return resources, nil
 }
 
-func (f *AMPWorkspace) Remove() error {
+type AMPWorkspace struct {
+	svc            *prometheusservice.PrometheusService
+	workspaceAlias *string
+	workspaceARN   *string
+	workspaceID    *string
+}
+
+func (f *AMPWorkspace) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteWorkspace(&prometheusservice.DeleteWorkspaceInput{
-		WorkspaceId: f.workspaceId,
+		WorkspaceId: f.workspaceID,
 	})
 
 	return err
@@ -59,7 +75,7 @@ func (f *AMPWorkspace) Properties() types.Properties {
 	properties.
 		Set("WorkspaceAlias", f.workspaceAlias).
 		Set("WorkspaceARN", f.workspaceARN).
-		Set("WorkspaceId", f.workspaceId)
+		Set("WorkspaceId", f.workspaceID)
 
 	return properties
 }
