@@ -1,36 +1,52 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/rds"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
+const RDSDBSubnetGroupResource = "RDSDBSubnetGroup"
+
+func init() {
+	registry.Register(&registry.Registration{
+		Name:     RDSDBSubnetGroupResource,
+		Scope:    nuke.Account,
+		Resource: &RDSDBSubnetGroup{},
+		Lister:   &RDSDBSubnetGroupLister{},
+	})
+}
+
+type RDSDBSubnetGroupLister struct{}
+
 type RDSDBSubnetGroup struct {
 	svc  *rds.RDS
 	name *string
 	tags []*rds.Tag
 }
 
-func init() {
-	register("RDSDBSubnetGroup", ListRDSSubnetGroups)
-}
-
-func ListRDSSubnetGroups(sess *session.Session) ([]Resource, error) {
-	svc := rds.New(sess)
+func (l *RDSDBSubnetGroupLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+	svc := rds.New(opts.Session)
 
 	params := &rds.DescribeDBSubnetGroupsInput{MaxRecords: aws.Int64(100)}
 	resp, err := svc.DescribeDBSubnetGroups(params)
 	if err != nil {
 		return nil, err
 	}
-	var resources []Resource
+
+	var resources []resource.Resource
 	for _, subnetGroup := range resp.DBSubnetGroups {
 		tags, err := svc.ListTagsForResource(&rds.ListTagsForResourceInput{
 			ResourceName: subnetGroup.DBSubnetGroupArn,
 		})
-
 		if err != nil {
 			continue
 		}
@@ -40,13 +56,12 @@ func ListRDSSubnetGroups(sess *session.Session) ([]Resource, error) {
 			name: subnetGroup.DBSubnetGroupName,
 			tags: tags.TagList,
 		})
-
 	}
 
 	return resources, nil
 }
 
-func (i *RDSDBSubnetGroup) Remove() error {
+func (i *RDSDBSubnetGroup) Remove(_ context.Context) error {
 	params := &rds.DeleteDBSubnetGroupInput{
 		DBSubnetGroupName: i.name,
 	}
