@@ -1,24 +1,36 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/redshift"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type RedshiftSnapshot struct {
-	svc      *redshift.Redshift
-	snapshot *redshift.Snapshot
-}
+const RedshiftSnapshotResource = "RedshiftSnapshot"
 
 func init() {
-	register("RedshiftSnapshot", ListRedshiftSnapshots)
+	registry.Register(&registry.Registration{
+		Name:     RedshiftSnapshotResource,
+		Scope:    nuke.Account,
+		Resource: &RedshiftSnapshot{},
+		Lister:   &RedshiftSnapshotLister{},
+	})
 }
 
-func ListRedshiftSnapshots(sess *session.Session) ([]Resource, error) {
-	svc := redshift.New(sess)
-	resources := []Resource{}
+type RedshiftSnapshotLister struct{}
+
+func (l *RedshiftSnapshotLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := redshift.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &redshift.DescribeClusterSnapshotsInput{
 		MaxRecords: aws.Int64(100),
@@ -47,6 +59,11 @@ func ListRedshiftSnapshots(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+type RedshiftSnapshot struct {
+	svc      *redshift.Redshift
+	snapshot *redshift.Snapshot
+}
+
 func (f *RedshiftSnapshot) Properties() types.Properties {
 	properties := types.NewProperties().
 		Set("CreatedTime", f.snapshot.SnapshotCreateTime)
@@ -58,8 +75,7 @@ func (f *RedshiftSnapshot) Properties() types.Properties {
 	return properties
 }
 
-func (f *RedshiftSnapshot) Remove() error {
-
+func (f *RedshiftSnapshot) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteClusterSnapshot(&redshift.DeleteClusterSnapshotInput{
 		SnapshotIdentifier: f.snapshot.SnapshotIdentifier,
 	})
