@@ -1,22 +1,39 @@
 package resources
 
 import (
-	"fmt"
+	"context"
+
+	"github.com/gotidy/ptr"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/route53"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
+const Route53HealthCheckResource = "Route53HealthCheck"
+
 func init() {
-	register("Route53HealthCheck", ListRoute53HealthChecks)
+	registry.Register(&registry.Registration{
+		Name:     Route53HealthCheckResource,
+		Scope:    nuke.Account,
+		Resource: &Route53HealthCheck{},
+		Lister:   &Route53HealthCheckLister{},
+	})
 }
 
-func ListRoute53HealthChecks(sess *session.Session) ([]Resource, error) {
-	svc := route53.New(sess)
+type Route53HealthCheckLister struct{}
+
+func (l *Route53HealthCheckLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := route53.New(opts.Session)
 	params := &route53.ListHealthChecksInput{}
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 
 	for {
 		resp, err := svc.ListHealthChecks(params)
@@ -30,9 +47,11 @@ func ListRoute53HealthChecks(sess *session.Session) ([]Resource, error) {
 				id:  check.Id,
 			})
 		}
-		if aws.BoolValue(resp.IsTruncated) == false {
+
+		if !aws.BoolValue(resp.IsTruncated) {
 			break
 		}
+
 		params.Marker = resp.NextMarker
 	}
 
@@ -44,7 +63,7 @@ type Route53HealthCheck struct {
 	id  *string
 }
 
-func (hz *Route53HealthCheck) Remove() error {
+func (hz *Route53HealthCheck) Remove(_ context.Context) error {
 	params := &route53.DeleteHealthCheckInput{
 		HealthCheckId: hz.id,
 	}
@@ -63,5 +82,5 @@ func (hz *Route53HealthCheck) Properties() types.Properties {
 }
 
 func (hz *Route53HealthCheck) String() string {
-	return fmt.Sprintf("%s", *hz.id)
+	return ptr.ToString(hz.id)
 }
