@@ -1,30 +1,44 @@
 package resources
 
 import (
+	"context"
+	"errors"
+
 	"github.com/aws/aws-sdk-go/aws/awserr"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/sns"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type SNSPlatformApplication struct {
-	svc *sns.SNS
-	ARN *string
-}
+const SNSPlatformApplicationResource = "SNSPlatformApplication"
 
 func init() {
-	register("SNSPlatformApplication", ListSNSPlatformApplications)
+	registry.Register(&registry.Registration{
+		Name:     SNSPlatformApplicationResource,
+		Scope:    nuke.Account,
+		Resource: &SNSPlatformApplication{},
+		Lister:   &SNSPlatformApplicationLister{},
+	})
 }
 
-func ListSNSPlatformApplications(sess *session.Session) ([]Resource, error) {
-	svc := sns.New(sess)
-	resources := []Resource{}
+type SNSPlatformApplicationLister struct{}
+
+func (l *SNSPlatformApplicationLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := sns.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &sns.ListPlatformApplicationsInput{}
 
 	for {
 		resp, err := svc.ListPlatformApplications(params)
 		if err != nil {
-			awsErr, ok := err.(awserr.Error)
+			var awsErr awserr.Error
+			ok := errors.As(err, &awsErr)
 			if ok && awsErr.Code() == "InvalidAction" && awsErr.Message() == "Operation (ListPlatformApplications) is not supported in this region" {
 				// AWS answers with InvalidAction on regions that do not
 				// support ListPlatformApplications.
@@ -49,8 +63,12 @@ func ListSNSPlatformApplications(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *SNSPlatformApplication) Remove() error {
+type SNSPlatformApplication struct {
+	svc *sns.SNS
+	ARN *string
+}
 
+func (f *SNSPlatformApplication) Remove(_ context.Context) error {
 	_, err := f.svc.DeletePlatformApplication(&sns.DeletePlatformApplicationInput{
 		PlatformApplicationArn: f.ARN,
 	})
