@@ -1,26 +1,37 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/waf"
 	"github.com/aws/aws-sdk-go/service/wafregional"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type WAFRegionalRegexPatternString struct {
-	svc           *wafregional.WAFRegional
-	patternSetid  *string
-	patternString *string
-}
+const WAFRegionalRegexPatternStringResource = "WAFRegionalRegexPatternString"
 
 func init() {
-	register("WAFRegionalRegexPatternString", ListWAFRegionalRegexPatternString)
+	registry.Register(&registry.Registration{
+		Name:     WAFRegionalRegexPatternStringResource,
+		Scope:    nuke.Account,
+		Resource: &WAFRegionalRegexPatternString{},
+		Lister:   &WAFRegionalRegexPatternStringLister{},
+	})
 }
 
-func ListWAFRegionalRegexPatternString(sess *session.Session) ([]Resource, error) {
-	svc := wafregional.New(sess)
-	resources := []Resource{}
+type WAFRegionalRegexPatternStringLister struct{}
+
+func (l *WAFRegionalRegexPatternStringLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := wafregional.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &waf.ListRegexPatternSetsInput{
 		Limit: aws.Int64(50),
@@ -43,7 +54,7 @@ func ListWAFRegionalRegexPatternString(sess *session.Session) ([]Resource, error
 			for _, patternString := range regexPatternSet.RegexPatternSet.RegexPatternStrings {
 				resources = append(resources, &WAFRegionalRegexPatternString{
 					svc:           svc,
-					patternSetid:  set.RegexPatternSetId,
+					patternSetID:  set.RegexPatternSetId,
 					patternString: patternString,
 				})
 			}
@@ -59,7 +70,13 @@ func ListWAFRegionalRegexPatternString(sess *session.Session) ([]Resource, error
 	return resources, nil
 }
 
-func (r *WAFRegionalRegexPatternString) Remove() error {
+type WAFRegionalRegexPatternString struct {
+	svc           *wafregional.WAFRegional
+	patternSetID  *string
+	patternString *string
+}
+
+func (r *WAFRegionalRegexPatternString) Remove(_ context.Context) error {
 	tokenOutput, err := r.svc.GetChangeToken(&waf.GetChangeTokenInput{})
 	if err != nil {
 		return err
@@ -67,7 +84,7 @@ func (r *WAFRegionalRegexPatternString) Remove() error {
 
 	_, err = r.svc.UpdateRegexPatternSet(&waf.UpdateRegexPatternSetInput{
 		ChangeToken:       tokenOutput.ChangeToken,
-		RegexPatternSetId: r.patternSetid,
+		RegexPatternSetId: r.patternSetID,
 		Updates: []*waf.RegexPatternSetUpdate{
 			{
 				Action:             aws.String("DELETE"),
@@ -81,6 +98,6 @@ func (r *WAFRegionalRegexPatternString) Remove() error {
 
 func (r *WAFRegionalRegexPatternString) Properties() types.Properties {
 	return types.NewProperties().
-		Set("RegexPatternSetID", r.patternSetid).
+		Set("RegexPatternSetID", r.patternSetID).
 		Set("patternString", r.patternString)
 }
